pub fn dup_assign_error(key: &Token, other: &Token, allow_inject: AllowInject)Expand description
Warns about a duplicate key = value in a database item.
key is the new one, other is the old one.
pub fn dup_assign_error(key: &Token, other: &Token, allow_inject: AllowInject)Warns about a duplicate key = value in a database item.
key is the new one, other is the old one.